@@ -1,7 +1,3 @@
-__author__ = 'Nikos Karaiskos'
-__email__ = 'nikolaos.karaiskos@mdc-berlin.de'
-__version__ = '0.1.5'
-
 from ._stimwrap import get_container, \
     get_dataset_names, \
     get_dataset, \
